@@ -22,7 +22,7 @@ from calculate.lib.utils.files import FilesError
 from calculate.update.emerge_parser import EmergeError
 from calculate.update.update import UpdateError
 from ..datavars import BuilderError
-from calculate.lib.utils.portage import GitError
+from calculate.lib.utils.git import GitError
 from calculate.install.distr import DistributiveError
 from calculate.builder.variables.action import Actions
 
